/*
 * distroquery_functions - Basic functions used by distroquery
 *
 * Copyright (C) 2024 by Silvan Calarco <silvan.calarco@mambasoft.it>
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of version 2 of the GNU General Public License as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY, to the extent permitted by law; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef __DISTROQUERY_FUNCTIONS_H
#define __DISTROQUERY_FUNCTIONS_H

#include <iostream>
#include <vector>
#include <sqlite3.h>

using namespace std;

string rpmSenseFlagsToString(int flags);
vector<string> split(string str, string token);
sqlite3* openRepositoryDatabase(struct configTag* ct, string arch = "", string append = "");
int sqlite3_find_column_id(sqlite3_stmt *stmt, const char* table, const char* name);

#define HDSIZE 16
#define SSSIZE 24

extern "C" typedef char humanDate[HDSIZE];
extern "C" typedef char sizeString[SSSIZE];

extern "C" char *humanSize(long long sbytes, sizeString *s);
extern "C" humanDate *simpleTimeToTemplate(long calendartime, const char* templ, humanDate * strdate);
extern "C" humanDate *simpleTimeToHuman(long calendartime, humanDate * strdate);
extern "C" const char *htmlclean(const char *source,char *dest,unsigned int max);
extern "C" const char *htmlcleanNoBr(const char *source,char *dest,unsigned int max);
extern "C" int get_favicon_from_url(const char* url,char *buf,int bufsize);
extern "C" void backtraceHandler(int sig);
extern "C" struct configTag* findRepositoryByTag(const char *tag);
extern "C" struct configTag* read_configuration(const char *confFile);

#endif // __DISTROQUERY_FUNCTIONS_H
